@@ -8,7 +8,7 @@ def translate_usernames_to_ids():
     users = client.users.translate_usernames_to_ids(['lirik', 'giantwaffle'])
 
     for user in users:
-        print('%s: %s' % (user.name, user.id))
+        print('{}: {}'.format(user.name, user.id))
 
 
 if __name__ == '__main__':
