@@ -14,7 +14,7 @@ class Channels(TwitchAPI):
         return Channel.construct_from(response)
 
     def get_by_id(self, channel_id):
-        response = self._request_get('channels/%s' % channel_id)
+        response = self._request_get('channels/{}'.format(channel_id))
         return Channel.construct_from(response)
 
     @oauth_required
@@ -32,12 +32,12 @@ class Channels(TwitchAPI):
         post_data = {
             'channel': data
         }
-        response = self._request_put('channels/%s' % channel_id, post_data)
+        response = self._request_put('channels/{}'.format(channel_id), post_data)
         return Channel.construct_from(response)
 
     @oauth_required
     def get_editors(self, channel_id):
-        response = self._request_get('channels/%s/editors' % channel_id)
+        response = self._request_get('channels/{}/editors'.format(channel_id))
         return [User.construct_from(x) for x in response['users']]
 
     def get_followers(self, channel_id, limit=25, offset=0, cursor=None, direction=DIRECTION_DESC):
@@ -46,7 +46,7 @@ class Channels(TwitchAPI):
                 'Maximum number of objects returned in one request is 100')
         if direction not in DIRECTIONS:
             raise TwitchAttributeException(
-                'Direction is not valid. Valid values are %s' % DIRECTIONS)
+                'Direction is not valid. Valid values are {}'.format(DIRECTIONS))
 
         params = {
             'limit': limit,
@@ -55,11 +55,11 @@ class Channels(TwitchAPI):
         }
         if cursor is not None:
             params['cursor'] = cursor
-        response = self._request_get('channels/%s/follows' % channel_id, params=params)
+        response = self._request_get('channels/{}/follows'.format(channel_id), params=params)
         return [Follow.construct_from(x) for x in response['follows']]
 
     def get_teams(self, channel_id):
-        response = self._request_get('channels/%s/teams' % channel_id)
+        response = self._request_get('channels/{}/teams'.format(channel_id))
         return [Team.construct_from(x) for x in response['teams']]
 
     @oauth_required
@@ -69,18 +69,18 @@ class Channels(TwitchAPI):
                 'Maximum number of objects returned in one request is 100')
         if direction not in DIRECTIONS:
             raise TwitchAttributeException(
-                'Direction is not valid. Valid values are %s' % DIRECTIONS)
+                'Direction is not valid. Valid values are {}'.format(DIRECTIONS))
 
         params = {
             'limit': limit,
             'offset': offset,
             'direction': direction
         }
-        response = self._request_get('channels/%s/subscriptions' % channel_id, params=params)
+        response = self._request_get('channels/{}/subscriptions'.format(channel_id), params=params)
         return [Subscription.construct_from(x) for x in response['subscriptions']]
 
     def check_subscription_by_user(self, channel_id, user_id):
-        response = self._request_get('channels/%s/subscriptions/%s' % (channel_id, user_id))
+        response = self._request_get('channels/{}/subscriptions/{}'.format(channel_id, user_id))
         return Subscription.construct_from(response)
 
     def get_videos(self, channel_id, limit=10, offset=0, broadcast_type=BROADCAST_TYPE_HIGHLIGHT,
@@ -91,10 +91,12 @@ class Channels(TwitchAPI):
 
         if broadcast_type not in BROADCAST_TYPES:
             raise TwitchAttributeException(
-                'Broadcast type is not valid. Valid values are %s' % BROADCAST_TYPES)
+                'Broadcast type is not valid. Valid values are {}'.format(BROADCAST_TYPES))
 
         if sort not in VIDEO_SORTS:
-            raise TwitchAttributeException('Sort is not valid. Valid values are %s' % VIDEO_SORTS)
+            raise TwitchAttributeException(
+                'Sort is not valid. Valid values are {}'.format(VIDEO_SORTS)
+            )
 
         params = {
             'limit': limit,
@@ -104,7 +106,7 @@ class Channels(TwitchAPI):
         }
         if language is not None:
             params['language'] = language
-        response = self._request_get('channels/%s/videos' % channel_id, params=params)
+        response = self._request_get('channels/{}/videos'.format(channel_id), params=params)
         return [Video.construct_from(x) for x in response['videos']]
 
     @oauth_required
@@ -112,20 +114,20 @@ class Channels(TwitchAPI):
         data = {
             'duration': duration
         }
-        response = self._request_post('channels/%s/commercial' % channel_id, data=data)
+        response = self._request_post('channels/{}/commercial'.format(channel_id), data=data)
         return response
 
     @oauth_required
     def reset_stream_key(self, channel_id):
-        response = self._request_delete('channels/%s/stream_key' % channel_id)
+        response = self._request_delete('channels/{}/stream_key'.format(channel_id))
         return Channel.construct_from(response)
 
     def get_community(self, channel_id):
-        response = self._request_get('channels/%s/community' % channel_id)
+        response = self._request_get('channels/{}/community'.format(channel_id))
         return Community.construct_from(response)
 
     def set_community(self, channel_id, community_id):
-        self._request_put('channels/%s/community/%s' % (channel_id, community_id))
+        self._request_put('channels/{}/community/{}'.format(channel_id, community_id))
 
     def delete_from_community(self, channel_id):
-        self._request_delete('channels/%s/community' % channel_id)
+        self._request_delete('channels/{}/community'.format(channel_id))
